import time
def calcProd():
    #Calculate the product of the first 100,000 numbers.
    product = 1
    for i in range(1,100000):
        product = product * i
    return product
startTime = time.time()
prod=calcProd()
endTime = time.time()
print('The result is %s digits long.' % (len(str(prod))))
print('Took %s seconds ot calculate.' % (endTime - startTime))



#!Python3
# resizeAndAddLogo.py -- resizes all image incurrent working dir to fit
# in a 300*300 square, and adds catlog.png to the lower-right corner.
import os
from PIL import Image
os.chdir(r'D:\Python学习\automate_online-materials')
SQUARE_FIT_SIZE = 300
LOGO_FILENAME = 'catlogo.png'

logoIm = Image.open(LOGO_FILENAME)
logWidth,logHeight = logoIm.size
logoIm.save(os.path.join('withlog','yyy1.jpg'))

os.makedirs('withlog',exist_ok=True)
logoIm.save(os.path.join('withlog','yyy2.jpg'))

# Loop over all files in working directory
for filename in os.listdir('.'):
    if not (filename.endswith('.png') or filename.endswith('.jpg')) \
       or filename == LOGO_FILENAME:
        continue # skip non-image files and the logo file itself
    im = Image.open(filename)
    width,height = im.size
    if width > SQUARE_FIT_SIZE and height > SQUARE_FIT_SIZE:
        #Calculate the new width and height to resize to.
        if width > height:
            logHeight = int((SQUARE_FIT_SIZE / logWidth) * logHeight)
            logWidth = SQUARE_FIT_SIZE
        else:
            logWidth = int((SQUARE_FIT_SIZE/logHeight) * logWidth)
            logHeight = SQUARE_FIT_SIZE

        #Resize the image.
        print('Resizing %s ...' % (filename))
        logoIm.save(os.path.join('withlog','yyy.jpg'))
        logoIm = logoIm.resize((logWidth,logHeight))
    print('Adding logo to %s ...' % (filename))
    logoIm.save(os.path.join('withlog','xxx.jpg'))
    im.paste(logoIm,(width - logWidth,height - logHeight),logoIm)

    im.save(os.path.join('withlog',filename))
    



from O365 import Message
import csv
def send_email(file_name):
    credentials = ('c456c315-34fa-49a7-9e0c-3afb47ab492d', '5Dl8Q~xO~Zhucrs4_SskfQkmpItXUZ85qoTSic3s')

    with open(file_name,newline='',encoding='utf-8') as csvfile:
        sp = csv.reader(csvfile,delimiter=',',quoting=csv.QUOTE_NONE)
        for row in sp:            
            email=row[0]
            account=row[1]
            initpw=row[2]


            account = Account(credentials)

            if not account.is_authenticated:
                print(account.is_authenticated)
                account.authenticate(scopes=['basic', 'message_all'])

            m = account.new_message()
            m.to.add(email)
            m.subject = 'SAP Account Notification'
            m.body = 'Dear Colleague:\n'+ '    Your SAP account has been created.'+ '\n' +
                      '    Account ID:' + account + '\n'+ '    InitialPassword:' + initpw + '\n' +
                      '    Please login the following production url to check your account,'+ '\n' +
                      'And make sure you have changed this initial password after the fist login!'+'\n'+
                      r'        https://vmssapwepapp1.byton.com:44320/sap/bc/ui2/flp' + '\n' +
                      r'   Attentions:' + '\n' +                     
                      r'        1. Any new PR creator should reach out to Ivy Hou <> and Lorin Gu <> for training.' + '\n' +
                      r'        2. Access or authorization issues please directly reply back to me: xxxx@git.com>.' + '\n' +
                      r'        3. Ivy Hou <> and Lorin Gu <> will be your main contact for all the operation issues.' + '\n' +
                      r'Thanks!')
            m.send()


import win32api,win32con,time
for i in range(800):
    win32api.keybd_event(77,0,0,0)
    win32api.keybd_event(77,0,win32con.KEYEVENTF_KEYUP,0)
    win32api.keybd_event(90,0,0,0)
    win32api.keybd_event(90,0,win32con.KEYEVENTF_KEYUP,0)
    i = i + 1
    time.sleep(0.05)



#/usr/bin/python
# -*- coding: utf-8 -*-
import re,os
def readfile(x):
    out = open(x+"---output.temp",'a')
    with open(x,'r',encoding='utf8') as f:
        cc=f.read()
        print("===============begin find_tel")
        find_tel(cc,out)
        print("===============begin find mail")
        find_mail(cc,out)
        print("===============begin find thunder")
        find_thunder(cc,out)
    out.close()


def find_tel(a,out):
    tel=re.compile(r'''((\d{3}||\(\d{3}\))?(\s|\.|-)?(\d{3})(\s|\.|-)(\d{4})(\s*(ext|x|ext.)\s*(\d{2,5}))?)''',re.VERBOSE)
    tel1=re.compile(r'''(1\d{10}\D)''',re.VERBOSE)

    tels=[]
    out.write("Telephone List:\n")
    c=tel.findall(a)
    for i in c:        
        try:
            ac=re.compile('(\d)+')
            tels.append('-'.join([i[1],i[3],i[5]])+' ext. '+str(ac.search(i[6]).group(0)))
            out.write('-'.join([i[1],i[3],i[5]])+' ext. '+str(ac.search(i[6]).group(0)))
            out.write('\n')
        except AttributeError:
            tels.append('-'.join([i[1],i[3],i[5]]))
    c1=tel1.findall(a)
    for i in c1:        
        tels.append(i)
        print(i)
        out.write(i)
        out.write('\n')


def find_mail(a,out):
    email1 = re.compile(r'[\w\.-_]+@[\w.-_]+\.[\w]+',re.I)
    #email=re.compile(r'''(([a-zA-Z0-9_.%+-]+)+@([a-zA-Z0-9.-]+)(\.[a-zA-Z]{2,4}))''',re.I)
    mails=[]
    c=email1.findall(a)
    out.write("Email List:\n")
    for i in c:
        print(i)
        mails.append(i)
        out.write(i)
        out.write('\n')

def find_thunder(a,out):
    thunders=[]
    thu = re.compile("\'(thunder\:\/\/\S+)\'")
    cc = thu.findall(a)
    out.write("Thunder List:\n")
    for dd in cc:
        print(dd)
        thunders.append(dd)
        out.write(dd)
        out.write('\n')



#!/usr/bin/python3
# -*- coding: utf-8 -*-
from socket import *
from iptools import IpRange
import sys
import os
def portScanner(host,port):
    try:
        s = socket(AF_INET,SOCK_STREAM)
        host = str(host)
        port = int(port)
        s.connect((host,port))
        print('%s[+] %d open--------------------------------------' % (host,port))
        results.append(host+"-"+str(port)+" is open!\n")
        s.close()
    except:
        pass
        print('%s[-] %d close' % (host,port))
        #results.append(host+"-"+str(port)+"is closed!")
def main(argv):
    global results
    results=[]
    string_ip = "".join(argv[1])
    ports=[]
    string_port = "".join(argv[2])
    string_port=string_port.replace("[","").replace("]","")
    for i in string_port.split(","):
        if "-" in i:
            init_a=int(i.split("-")[0])
            while init_a<=int(i.split("-")[1]):
                ports.append(init_a)
                init_a=init_a+1
        else:
            ports.append(int(i))
    setdefaulttimeout(0.1)

    ip_list = IpRange(string_ip)
    for ip in ip_list:
        for p in ports:
            #if str(ip).split('.')[3] in ['1','10','100','200']:
            #    print(str(ip) + ':' + str(p) +' is scanning')
            portScanner(ip,p)
    log_name = "scan.log"
    if os.path.exists(log_name):
        os.remove(log_name)
    f = open(log_name,'w')
    f.close() 
    with open(log_name,"a") as f:
        for i in results:
            f.writelines(i)

        

if __name__ == '__main__':
    main(sys.argv)



import pymssql
import psycopg2
# user      用户名
# password  密码
# database  数据库名称
source_conn = pymssql.connect('127.0.0.1', 'sa', '231231', 'hotel')
source_cursor = source_conn.cursor()
source_cursor.execute('select * from dbo.cdsgus a where a.id > 1530001 order by a.id')

dest_conn=psycopg2.connect(database="dbname",user="xxx",password="xxxx",host="xxxxx",port="ports")
dest_cursor = dest_conn.cursor()

for i in range(1,2010):
    data = source_cursor.fetchmany(10000)
    dest_cursor.executemany("insert into records values (%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s)",data)
    dest_conn.commit()
    print("The ",i, " batch has inserted!")

dest_conn.close()
source_conn.close()



#!/usr/bin/python3
import json
import requests
import hashlib
import os
import exiftool
import datetime
import time
from PIL import Image
import imagehash
import shutil


class Checked_File:

    def __init__(self,file_loc):
        self.file_loc = file_loc
        self.b_name = os.path.basename(self.file_loc)
        self.dir_name = os.path.dirname(self.file_loc)
    
    def get_md5(self):
        the_md5=hashlib.md5()
        hash = ''
        with open(self.file_loc,'rb') as f:
            the_md5.update(f.read())
            hash = the_md5.hexdigest()
        return hash

    def get_metadata(self):
        """
        EXIF:Model
        Checked_File:MIMEType
        EXIF:Make
        """
        metadata = {}
        with exiftool.ExifToolHelper() as et:
            try:
                metadata = et.get_metadata(self.file_loc)
                exif = {}
                for d in metadata:
                    exif.update(d)
                return exif
            except:
                return {}

    def get_maker(self):
        exif = self.get_metadata()
        if exif.get("EXIF:Make") is None:
                return "NON"
        else:
            return exif.get("EXIF:Make").strip().replace(" ","")+"-"+exif.get("EXIF:Model").strip().replace(" ","")


    def get_type(self):
        exif = self.get_metadata()
        if exif.get("Checked_File:Checked_FileType") is None:
            if os.path.splitext(self.b_name)[1][1:].upper() != "":
                return os.path.splitext(self.b_name)[1][1:].upper()
            else:
                return "NON"
        else:
            return exif.get("Checked_File:Checked_FileType")
        return "NON"


    def get_create_day(self):
        exif = self.get_metadata()
        if exif.get("EXIF:DateTimeOriginal") is not None:
            return "{:20.10}".format(exif.get("EXIF:DateTimeOriginal")).replace(":","-").replace(" ","")
        elif exif.get("EXIF:FileInodeChangeDate") is not None:
            return "{:20.10}".format(exif.get("EXIF:FileInodeChangeDate")).replace(":","-").replace(" ","")
        elif exif.get("EXIF:FileModifyDate") is not None:
            return "{:20.10}".format(exif.get("EXIF:FileModifyDate")).replace(":","-").replace(" ","")

        create_day =datetime.datetime.strptime(time.ctime(os.path.getctime(self.file_loc)), "%a %b %d %H:%M:%S %Y").strftime("%Y-%m-%d")
        return create_day



    def get_create_month(self):
        exif = self.get_metadata()
        if exif.get("EXIF:DateTimeOriginal") is not None:
            return "{:20.7}".format(exif.get("EXIF:DateTimeOriginal")).replace(":","-").replace(" ","")
        elif exif.get("EXIF:FileInodeChangeDate") is not None:
            return "{:20.7}".format(exif.get("EXIF:FileInodeChangeDate")).replace(":","-").replace(" ","")
        elif exif.get("EXIF:FileModifyDate") is not None:
            return "{:20.7}".format(exif.get("EXIF:FileModifyDate")).replace(":","-").replace(" ","")
        create_month =datetime.datetime.strptime(time.ctime(os.path.getctime(self.file_loc)), "%a %b %d %H:%M:%S %Y").strftime("%Y-%m")
        return create_month


    def get_geo_address(self):
        dict={}
        exif = self.get_metadata()
        if exif.get("Composite:GPSLatitude") is not None:
            geo='{:.4f}'.format(exif.get("Composite:GPSLongitude"))+","+'{:.4f}'.format(exif.get("Composite:GPSLatitude"))
            gaode=json.load(open(os.path.join(os.path.dirname(os.getcwd()),"config","gaode.json")))
            base=gaode.get("base")
            key = gaode.get("key")
            parameters={"location":geo,"key":key}
            try:
                response = requests.get(base, parameters)
                if response.status_code == 200:
                    address = response.json()
                    dict["city"]=address.get("regeocode").get("addressComponent").get("city")
                    dict["province"]=address.get("regeocode").get("addressComponent").get("province")
                    dict["district"]=address.get("regeocode").get("addressComponent").get("district")
                    dict["country"]=address.get("regeocode").get("addressComponent").get("country")
                    dict["address"]=address.get("regeocode").get("formatted_address")
                else:
                    pass
            except:
                pass
            return dict
    def is_same(self,cmp_file):
        """
        返回same如果相同
        返回similar如果相似
        返回空如果不同
        """
        media2= Checked_File(cmp_file)
        hash2=media2.get_md5()
        hash1=self.get_md5()
        status = ""
        if hash1==hash2:
            status = "same"
        else:
            hash11 =  imagehash.average_hash(Image.open(self.file_loc))
            hash12 =  imagehash.average_hash(Image.open(cmp_file))
            if (hash11 == hash12):
                status = "similar"
        return status

    def move_to(self,dest):
        hash1=self.get_md5()
        log=""
        if os.path.exists(os.path.join(dest,self.b_name)):
            media2 = Checked_File(os.path.join(dest,self.b_name))
            hash2=media2.get_md5()
            if hash1 == hash2:
                log=['delete',self.b_name,self.file_loc,os.path.join(dest,self.b_name),os.path.getsize(self.file_loc),hash1]
                os.remove(self.file_loc)
            else:
                new_file_name  = os.path.join(dest,os.path.splitext(self.b_name)[0] + "_1" + os.path.splitext(self.b_name)[1])
                while os.path.exists(new_file_name):
                    new_file_name  = os.path.join(dest,os.path.splitext(os.path.basename(new_file_name))[0] + "_1" + os.path.splitext(new_file_name)[1])
                shutil.move(self.file_loc,os.path.join(new_file_name))
                print("shutil move,"+ "from,"+ self.file_loc + ",to,"+ new_file_name )
                log=['rename',self.b_name,self.file_loc,new_file_name,os.path.getsize(new_file_name),hash1]
        else:
            shutil.move(self.file_loc,os.path.join(dest,self.b_name))
            print("shutil move,"+ "from,"+ self.file_loc + ",to,"+ os.path.join(dest,self.b_name))
            log=['move',self.b_name,self.file_loc,os.path.join(dest,self.b_name),os.path.getsize(os.path.join(dest,self.b_name)),hash1]
        return log

import os
import os.path
import csv
import stat
import time
import sqlite3
import imagehash
#引入folder里面的通用函数，例如file_move,get_db,update_db


class Check_Folder:
    """
    ### log 字段说明，从0到5
    ### ['duplicate',i,os.path.join(folder,i),'',os.path.getsize(os.path.join(folder,i)),hash]
    ### (action varchar(20),name varchar(200),source varchar(1000),dest varchar(1000),size varchar(50),md5 varchar(50))
    1. one_folder，把当前目录中所有子目录文件移动到根目录下，并删除空的文件夹
    2. check,检查当前目录中的所有文件，并删除重复文件（根据MD5值来判断）
    3. compare,比较当前folder和目标folder，如果文件存在于目标folder，则删除

    
    """
    global HASH_COLUMN
    HASH_COLUMN = 5
    global DEFAULT_LOC
    DEFAULT_LOC = os.path.join(os.environ['HOME'],".log")

    def __init__(self,folder_loc):
        self.folder_loc=folder_loc
        self.dir_name = os.path.dirname(folder_loc)

    def one_folder(self):
        folder = self.folder_loc
        one_log = self.init_log(os.path.basename(folder)+'_one.log')
        for i in os.listdir(folder):
            if os.path.isdir(os.path.join(folder,i)):
                if i[0] not in ['@','.']:
                    self.process_one(os.path.join(folder,i),folder,one_log)
        return one_log
    def process_one(self,folder,base_folder,log):
        for i in os.listdir(folder):
            if os.path.isdir(os.path.join(folder,i)):
                if i[0] not in ['@','.']:
                    self.process_one(os.path.join(folder,i),base_folder,log)
                else:
                    shutil.rmtree(os.path.join(folder,i),ignore_errors = True)
            else:
                check_file = Checked_File(os.path.join(folder,i))
                mov_log = check_file.move_to(self.folder_loc)
                with open(log,'a',newline='') as f:
                    writer = csv.writer(f)
                    writer.writerow(mov_log)
        if self.folder_loc != folder:
            os.rmdir(folder)

    def check(self):
        folder = self.folder_loc
        check_log = os.path.join(DEFAULT_LOC,os.path.basename(folder)+'_check.log')
        if os.path.exists(check_log):
            os.remove(check_log)
            with open(check_log, "w") as f:
                f.write("")
        global checking
        checking = []
        self.process_checking(folder,check_log)
        #conn = self.init_db(DEFAULT_DB)
        #init_db_table(conn,os.path.basename(folder))
        #print(folder,check_log,conn)
        #update_db_record(os.path.basename(folder),check_log,conn)
        return checking

    def process_checking(self,folder,log):
        global checking
        for i in os.listdir(folder):            
            if os.path.isdir(os.path.join(folder,i)):
                if i[0] not in ['@','.']:
                    print(str(os.path.join(folder,i)) + " is not dummy folder")
                    self.process_checking(os.path.join(folder,i),log)
            else:
                media = Checked_File(os.path.join(folder,i))
                hash = media.get_md5()
                if hash is not None:
                    if hash in checking:
                        with open(log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(['duplicate',i,os.path.join(folder,i),'',os.path.getsize(os.path.join(folder,i)),hash])
                        os.remove(os.path.join(folder,i)) 
                    else:
                        with open(log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(['new',i,os.path.join(folder,i),'',os.path.getsize(os.path.join(folder,i)),hash])
                        checking.append(hash)
        return log

    def compare(self,std_folder):
        """
        用来对比文件夹cmp_folder和文件夹cmp_folder
        如果cmp_foler中的文件在ctd_folder中，则删除
        """
        #global compare
        #compare = []
        global checking
        cmp_folder=self.folder_loc
        cmp_log = self.init_log(os.path.basename(cmp_folder)+'_comp.log')
        check_log = os.path.join(DEFAULT_LOC,os.path.basename(std_folder)+'_check.log')
        if os.path.exists(check_log):
            std_log = check_log 
        else:
            check_folder=Check_Folder(std_folder)
            std_log = check_folder.check()
        self.process_comparing(self.folder_loc,std_log,cmp_log)
        return cmp_log

    def process_comparing(self,folder,std_log,cmp_log):
        global HASH_COLUMN
        for i in os.listdir(folder):
            if os.path.isdir(os.path.join(folder,i)):
                if i[0] not in ['@','.']:
                    print(str(os.path.join(folder,i)) + " is not dummy folder")
                    self.process_comparing(os.path.join(folder,i),std_log,cmp_log)
            else:
                media = Checked_File(os.path.join(folder,i))
                hash = media.get_md5()
                if hash is not None:
                    a = self.find_csv(std_log,hash,HASH_COLUMN)
                    if a is not None:
                        with open(cmp_log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(['duplicate',i,os.path.join(folder,i),a[2],os.path.getsize(os.path.join(folder,i)),hash])
                        os.remove(os.path.join(folder,i))
                    else:
                        with open(cmp_log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(['new',i,os.path.join(folder,i),'',os.path.getsize(os.path.join(folder,i)),hash])                   
                            #compare.append(hash)  

    def class_bysize(self,dstfold,large=1):
        folder = self.folder_loc
        class_by_size_log = self.init_log(os.path.basename(folder)+'_class_by_size.log')
        if not os.path.exists(os.path.join(dstfold,"large")):
            os.makedirs(os.path.join(dstfold,"large"))
        if not os.path.exists(os.path.join(dstfold,"small")):
            os.makedirs(os.path.join(dstfold,"small"))
        if os.path.exists(class_by_size_log):
            os.remove(class_by_size_log)
        f = open(class_by_size_log,'w')
        f.close()  
        self.process_bysize(folder,dstfold,class_by_size_log,large)
        return class_by_size_log

    def process_bysize(self,folder,dstfold,log,large):

        for i in os.listdir(folder):
            if i[0] not in ['@','.']:
                if os.path.isdir(os.path.join(folder,i)):
                    self.process_bysize(os.path.join(folder,i),dstfold,log,large)
                else:
                    size = os.path.getsize(os.path.join(folder,i))
                    a = Checked_File(os.path.join(folder,i))
                    if size < large*1024*1024:
                        xx=a.move_to(os.path.join(dstfold,"small"))
                        with open(log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(xx)
                            f.close()    
                    else:
                        xx=a.move_to(os.path.join(dstfold,"large"))
                        with open(log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(xx)
                            f.close()     

    def class_bytype(self,dstfold):
        folder = self.folder_loc
        class_by_type_log = self.init_log(os.path.basename(folder)+'_class_by_type.log')
        self.process_bytype(folder,dstfold,class_by_type_log)
        return class_by_type_log

    def process_bytype(self,folder,dstfold,log):
        for i in os.listdir(folder):
            if i[0] not in ['@','.']:
                if os.path.isdir(os.path.join(folder,i)):
                    self.process_bytype(os.path.join(folder,i),dstfold,log)
                else:
                    media = Checked_File(os.path.join(folder,i))
                    type = media.get_type()
                    if not (os.path.exists(os.path.join(dstfold,type))):
                        os.makedirs(os.path.join(dstfold,type))
                    a=Checked_File(os.path.join(folder,i))
                    result=a.move_to(os.path.join(dstfold,type))
                    with open(log,'a',newline='') as f:
                            writer = csv.writer(f)
                            writer.writerow(result)
        

    def class_bytime(self,desfold):
        folder= self.folder_loc
        log = self.init_log(os.path.basename(folder)+'_class_bytime.log')
        self.process_bytime(folder,desfold,log)
        return log

    def process_bytime(self,folder,desfold,log):
        for i in os.listdir(folder):
            if i[0] not in ['@','.']:
                if os.path.isdir(os.path.join(folder,i)):
                    self.process_bytime(os.path.join(folder,i),desfold,log)
                else:
                    media = Checked_File(os.path.join(folder,i))
                    a = media.get_create_day()          
                    if not os.path.exists(os.path.join(desfold,a)):
                        os.makedirs(os.path.join(desfold,a))
                    cc = Checked_File(os.path.join(folder,i))
                    temp_log = cc.move_to(os.path.join(desfold,a))
                    with open(log,'a',newline='') as f:
                        writer = csv.writer(f)
                        writer.writerow(temp_log)

    def class_bymonth(self,desfold):
        folder= self.folder_loc
        log = self.init_log(os.path.basename(folder)+'_class_bymonth.log')
        self.process_bymonth(folder,desfold,log)
        return log

    def process_bymonth(self,folder,desfold,log):
        for i in os.listdir(folder):
            if i[0] not in ['@','.']:
                if os.path.isdir(os.path.join(folder,i)):
                    self.process_bymonth(os.path.join(folder,i),desfold,log)
                else:
                    media = Checked_File(os.path.join(folder,i))
                    a = media.get_create_month()          
                    if not os.path.exists(os.path.join(desfold,a)):
                        os.makedirs(os.path.join(desfold,a))
                    cc = Checked_File(os.path.join(folder,i))
                    temp_log = cc.move_to(os.path.join(desfold,a))
                    with open(log,'a',newline='') as f:
                        writer = csv.writer(f)
                        writer.writerow(temp_log)



    def class_bymaker(self,desfold):
        folder = self.folder_loc
        log = self.init_log(os.path.basename(folder)+'_class_bymaker.log')
        self.process_bymaker(folder,desfold,log)
        return log

    def process_bymaker(self,folder,desfold,log):
        for i in os.listdir(folder):
            if i[0] not in ['@','.']:
                if os.path.isdir(os.path.join(folder,i)):
                    self.process_bymaker(os.path.join(folder,i),desfold,log)
                else:            
                    media = Checked_File(os.path.join(folder,i))
                    maker = media.get_maker()
                    if not os.path.exists(os.path.join(desfold,maker)):
                        os.makedirs(os.path.join(desfold,maker))
                    cc = Checked_File(os.path.join(folder,i))   
                    temp_log = cc.move_to(os.path.join(desfold,maker))   
                    with open(log,'a',newline='') as f:
                        writer = csv.writer(f)
                        writer.writerow(temp_log)       



    def init_log(self,logname):
        global DEFAULT_LOC
        if not os.path.exists(DEFAULT_LOC):
            os.mkdir(DEFAULT_LOC)
        if os.path.exists(os.path.join(DEFAULT_LOC,logname)):
            os.remove(os.path.join(DEFAULT_LOC,logname))
        f = open(os.path.join(DEFAULT_LOC,logname),'w')
        f.close() 
        return os.path.join(DEFAULT_LOC,logname)

    def find_csv(self,csv_file,key_words,column):
        with open(csv_file,'r') as f:
            reader = csv.reader(f,delimiter=",")
            for row in reader:
                if row[column] == key_words:
                    return row
        







        



#get the access token"
import requests
import sys

def get_access():
   a = requests.get("https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid=wweb64ffbfdd8bb120&corpsecret=Bl6QdD-rFhQ_QfeFf_s1Dd1_g4arHAqF4EjZvNmqLPY")
   access_token = eval(a.text)["access_token"]
   return access_token

def send_message(token,message):
   url = "https://qyapi.weixin.qq.com/cgi-bin/message/send?access_token=" + token
   paras = {
   "touser" : "TuDou",
   "agentid" : 1000002,
   "msgtype": "text",
   "text" : {
       "content" : "你的快递已到，请携带工卡前往邮件中心领取。\n出发前可查看<a href=\"http://work.weixin.qq.com\">邮件中心视频实况</a>，聪明避开排队。"
   },
   "safe":0,
   "enable_id_trans": 0,
   "enable_duplicate_check": 0,
   "duplicate_check_interval": 1800
   }

   paras["text"].update({"content": message})
   results = requests.post(url,json=paras)
   return results.status_code

if __name__ == "__main__":
   message = sys.argv[1]
   send_message(get_access(),message)



#!/usr/bin/env python
import urllib
import urllib.request


LOGIN = 'wesley'
PASSWD = "you'llNeverGuess"
URL = 'http://localhost'
REALM = 'Secure Archive'


def handler_version(url):
    from urllib import parse as urlparse
    hdlr = urllib.request.HTTPBasicAuthHandler()
    hdlr.add_password(REALM,urllib.parse.urlparse(url)[1],LOGIN,PASSWD)
    opener = urllib.request.build_opener(hdlr)
    urllib.request.install_opener(opener)
    return url

def request_version(url):
    from base64 import encodestring
    req = urllib.request.Request(url)
    b64str = encodestring('%s:%s' % (LOGIN,PASSWD))[:-1]
    req.add_header("Authorization","Basic %s" % b64str)
    return req

for funcType in ('handler','request'):
    print('*** Using %s:' % funcType.upper())
    url = eval('%s_version' % funcType)(URL)
    f = urllib.request.urlopen(url)
    print(f.readline())
    f.close()



#!/usr/bin/env python
from socket import *
from time import ctime
HOST = ''
PORT = 21567
BUFSIZ = 1024
ADDR = (HOST,PORT)
udpSerSock = socket(AF_INET,SOCK_DGRAM)
udpSerSock.bind(ADDR)
while True:
    print('waiting for message...')
    data,addr = udpSerSock.recvfrom(BUFSIZ)
    print('....message from:',addr)
    udpSerSock.sendto(b'[%s] %s' % (bytes(ctime(),'utf-8'),data),addr)
    print(str('....received from and returned to:')+str(addr))
udpSerSock.close()



import re
import os
global pc_list
pc_list = []
def read_file_regex(filename, regex):
    with open(filename, "r") as f:
        for line in f:
            match = re.search(regex, line)
            if match:
                #print(match.group())
                a = match.group()
                if a in pc_list:
                    pass 
                else:
                    pc_list.append(a)


def read_folder_regex(folder, regex):
    for i in os.listdir(folder):
        if os.path.isdir(os.path.join(folder, i)):
            if i[0] not in ['@', '.']:
                print(str(os.path.join(folder, i)) + " is not dummy folder")
                read_folder_regex(os.path.join(folder, i), regex)
        else:
            read_file_regex(os.path.join(folder, i),regex)


if __name__ == "__main__":
    folder = "/mnt/d/shared/log3"
    regex = r"[a-zA-Z0-9]{8,12}\.legendbiotech.local"
    read_folder_regex(folder,regex)
    for i in pc_list:
        print(i)




import os
import bs4
import lxml
import urllib.request
import re
#get the contents of website
con = urllib.request.urlopen('http://www.ishadowsocks.net/')
soup = bs4.BeautifulSoup(con.read(),'lxml')
#print(soup.prettify())

servers = soup.select('#free > div > div:nth-of-type(2) > div')
a=[]


for i in servers:
#    print(ko.search(str(i.to_text)))
#    print(i.contents[1].string)
#    print(i.contents[1].string.index(':'))
    a.append({'server':i.contents[1].string[i.contents[1].string.index(':')+1:],
              'port':i.contents[3].string[i.contents[3].string.index(':')+1:],
              'password':i.contents[5].string[i.contents[5].string.index(':')+1:],
              'encrypt':i.contents[7].string[i.contents[7].string.index(':')+1:]
              })

                     
con.close()



from setuptools import setup, find_packages
import sys, os


with open("README.md","r") as fh:
      long_description=fh.read()



setup(name="njnuko",
      version="5.2.2",
      description="njnuko tools,need to install sudo apt install exiftool",
      long_description=long_description,
      classifiers=[], 
      keywords='files sorting',
      author='njnuko',
      author_email='njnuko@163.com',
      url='https://github.com/njnuko/njnuko',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      install_requires=['imagehash','requests','Pillow','pyexiftool==0.4.13','iptools'],
      entry_points="",
      )
